@@ -13,7 +13,7 @@ class ModificationLockInfo(AbstractApiClass):
         self.organization_groups = organizationGroups
 
     def __repr__(self):
-        return f"ModificationLockInfo(modification_lock={repr(self.modification_lock)}, user_emails={repr(self.user_emails)}, organization_groups={repr(self.organization_groups)})"
+        return f"ModificationLockInfo(modification_lock={repr(self.modification_lock)},\n  user_emails={repr(self.user_emails)},\n  organization_groups={repr(self.organization_groups)})"
 
     def to_dict(self):
         return {'modification_lock': self.modification_lock, 'user_emails': self.user_emails, 'organization_groups': self.organization_groups}
