@@ -14,7 +14,7 @@ class RefreshSchedule(AbstractApiClass):
         self.refresh_type = refreshType
 
     def __repr__(self):
-        return f"RefreshSchedule(refresh_policy_id={repr(self.refresh_policy_id)}, next_run_time={repr(self.next_run_time)}, cron={repr(self.cron)}, refresh_type={repr(self.refresh_type)})"
+        return f"RefreshSchedule(refresh_policy_id={repr(self.refresh_policy_id)},\n  next_run_time={repr(self.next_run_time)},\n  cron={repr(self.cron)},\n  refresh_type={repr(self.refresh_type)})"
 
     def to_dict(self):
         return {'refresh_policy_id': self.refresh_policy_id, 'next_run_time': self.next_run_time, 'cron': self.cron, 'refresh_type': self.refresh_type}
