@@ -20,7 +20,7 @@ class TrainingConfigOptions(AbstractApiClass):
         self.last_model_value = lastModelValue
 
     def __repr__(self):
-        return f"TrainingConfigOptions(name={repr(self.name)}, data_type={repr(self.data_type)}, value_type={repr(self.value_type)}, value_options={repr(self.value_options)}, value={repr(self.value)}, default={repr(self.default)}, options={repr(self.options)}, description={repr(self.description)}, required={repr(self.required)}, last_model_value={repr(self.last_model_value)})"
+        return f"TrainingConfigOptions(name={repr(self.name)},\n  data_type={repr(self.data_type)},\n  value_type={repr(self.value_type)},\n  value_options={repr(self.value_options)},\n  value={repr(self.value)},\n  default={repr(self.default)},\n  options={repr(self.options)},\n  description={repr(self.description)},\n  required={repr(self.required)},\n  last_model_value={repr(self.last_model_value)})"
 
     def to_dict(self):
         return {'name': self.name, 'data_type': self.data_type, 'value_type': self.value_type, 'value_options': self.value_options, 'value': self.value, 'default': self.default, 'options': self.options, 'description': self.description, 'required': self.required, 'last_model_value': self.last_model_value}
